@@ -47,7 +47,7 @@ from matplotlib import pyplot as plt
 from scipy.sparse.linalg import svds
 # from sklearn.decomposition import PCA
 from scipy.sparse import csr_matrix, _sparsetools
-from .merging import minimum_spanning_tree_agglomerate 
+# from .merging import minimum_spanning_tree_agglomerate 
 # from scipy.sparse import csr_matrix
 # from scipy.sparse.csgraph import shortest_path
 np.random.seed(0)
@@ -97,7 +97,7 @@ class CLASSIX:
         and an object is less than or equal to the tolerance, the object will be allocated 
         to the group which the starting point belongs to. 
     
-    group_merging : str, {'density', 'distance', 'scc-distance', 'mst-distance'}, default='distance'
+    group_merging : str, {'density', 'distance'}, default='distance'
         The method for merging the groups. 
         - 'density': two groups are merged if the density of data points in their intersection 
            is at least as high the smaller density of both groups. This option uses the disjoint 
@@ -105,10 +105,6 @@ class CLASSIX:
         - 'distance': two groups are merged if the distance of their starting points is at 
            most scale*radius (the parameter above). This option uses the disjoint 
            set structure to speedup agglomerate.
-        - 'scc-distance': calculate the distance-based merging by Tarjan's algorithm for finding
-           strongly connected components.
-        - 'mst-distance': it is also a distance based group_merging, but use minimum spanning tree instead
-           in the second stage with cutoff_scale scale*radius.
     
     minPts : int, default=0
         Clusters with less than minPts points are classified as abnormal clusters.  
@@ -176,7 +172,20 @@ class CLASSIX:
         
     """
         
-
+    # deprecated descriptions
+    # group_merging : str, {'density', 'distance', 'scc-distance', 'mst-distance'}, default='distance'
+    #     The method for merging the groups. 
+    #     - 'density': two groups are merged if the density of data points in their intersection 
+    #        is at least as high the smaller density of both groups. This option uses the disjoint 
+    #        set structure to speedup agglomerate.
+    #     - 'distance': two groups are merged if the distance of their starting points is at 
+    #        most scale*radius (the parameter above). This option uses the disjoint 
+    #        set structure to speedup agglomerate.
+    #     - 'scc-distance': calculate the distance-based merging by Tarjan's algorithm for finding
+    #        strongly connected components.
+    #     - 'mst-distance': it is also a distance based group_merging, but use minimum spanning tree instead
+    #        in the second stage with cutoff_scale scale*radius.
+        
     def __init__(self, sorting="pca", radius=0.5, minPts=0, group_merging="distance", norm=True, scale=1.5, post_alloc=True, n_jobs=-1, verbose=1): 
         # deprecated parameter (15/07/2021): noise_percent=0, distance_scale=1, eta=1, cython=True
         # eta (deprecated): float, default=1.0
@@ -529,11 +538,11 @@ class CLASSIX:
         
         # calculate the overall volume of the combination of the clusters,
         # hence only compare their neighbor clusters
-        if method == "mst-distance":
-            self.merge_groups = minimum_spanning_tree_agglomerate(splist, radius=radius, scale=self.scale)
-        
-        elif method == 'scc-distance':
-            self.merge_groups = scc_agglomerate(splist, radius=radius, scale=self.scale, n_jobs=self.n_jobs)
+        # if method == "mst-distance":
+        #     self.merge_groups = minimum_spanning_tree_agglomerate(splist, radius=radius, scale=self.scale)
+        # 
+        # elif method == 'scc-distance':
+        #     self.merge_groups = scc_agglomerate(splist, radius=radius, scale=self.scale, n_jobs=self.n_jobs)
         
         # --Deprecated 
         # elif method == 'trivial-distance': # deprecated method: brute force
@@ -552,7 +561,7 @@ class CLASSIX:
             # we employ an intutive and simple way to implement merging groups, resulting in a fast clustering
             # self.merge_groups = merge_pairs_dr(self.connected_pairs)
         
-        else:
+        # else:
             # print("clusters merging initialize...")
             self.merge_groups, self.connected_pairs = fast_agglomerate(data, splist, radius, method, scale=self.scale)
             # self.check_labels = labels
